@@ -1,6 +1,3 @@
-import time
-
-# RAN ON CORTEX M3, 64kb RAM
 def tr_to_dfg0(tr, dfg):
     if len(tr) > 0:
         i = 0
@@ -33,21 +30,5 @@ def trs_to_dfg(trs):
     dfg[0] = tuple(dfg[0])
     dfg[2] = tuple(dfg[2])
     dfg[3] = tuple(dfg[3])
+    dfg = tuple(dfg)
     return dfg
-
-
-def main():
-    dfg = [[], dict(), set(), set(), dict()]
-    dfg = tr_to_dfg(("A", "B", "C"), dfg)
-    dfg = tr_to_dfg(("A", "B"), dfg)
-    dfg[0] = tuple(dfg[0])
-    dfg[2] = tuple(dfg[2])
-    dfg[3] = tuple(dfg[3])
-    print(dfg)
-
-
-if __name__ == "__main__":
-    aa = time.ticks_ms()
-    main()
-    bb = time.ticks_ms()
-    print(bb-aa)
