@@ -1,7 +1,3 @@
-import time
-
-# RAN ON CORTEX M3, 64kb RAM
-
 def exp_tr_cid(tr, sep, ci):
     for act in tr:
         print("%s%s%s" % (ci, sep, act))
@@ -21,15 +17,3 @@ def exp_trs(trs, sep, ci, ai):
         else:
             exp_tr_cid(trs[i], ",", str(i))
         i = i + 1
-
-def main():
-    exp_hea(",", "case:concept:name", "concept:name")
-    exp_tr_cid(("A", "B", "C"), ",", "c1")
-    exp_tr_cid(("A", "B"), ",", "c2")
-
-
-if __name__ == "__main__":
-    aa = time.ticks_ms()
-    main()
-    bb = time.ticks_ms()
-    print(bb-aa)
