@@ -1,6 +1,3 @@
-import time
-
-# RAN ON CORTEX M3, 64kb RAM
 def st_exp():
     print("<?xml version='1.0' encoding='UTF-8'?>")
     print("<log>")
@@ -27,17 +24,3 @@ def exp_tr(tr):
 
 def end_exp():
     print("</log>")
-
-
-def main():
-    st_exp()
-    exp_tr_cid(["A", "B", "C"], "case1")
-    exp_tr(["A", "B"])
-    end_exp()
-
-
-if __name__ == "__main__":
-    aa = time.ticks_ms()
-    main()
-    bb = time.ticks_ms()
-    print(bb-aa)
